<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="main">
 *
 * @package WordPress
 * @subpackage SimplyBiz
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>" />
<title><?php
	/*
	 * Print the <title> tag based on what is being viewed.
	 * We filter the output of wp_title() a bit -- see
	 * simplybiz_filter_wp_title() in functions.php.
	 */
	wp_title( '|', true, 'right' );

	?></title>
<?php
	/* Adding meta tags for better SEO
	 * simplybiz_create_metadata() in functions.php.
	 */
	simplybiz_create_metadata();
?>
<link rel="profile" href="http://gmpg.org/xfn/11" />
<link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo( 'stylesheet_url' ); ?>" />
<?php if(get_option("simplybiz_colorscheme") <> "" && get_option("simplybiz_colorscheme") <> "default") : $skin = get_option("simplybiz_colorscheme"); ?>
<link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo( 'template_directory' ); ?>/library/color-scheme/<?php echo $skin; ?>/style-<?php echo $skin; ?>.css" />
<?php endif; ?>
<!--[if IE]>
<link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo( 'template_directory' ); ?>/style-ie.css" />
<![endif]-->
<?php
	/* Adding custom css file for customization if enabled
	 * in theme option.
	 */
	if(get_option("simplybiz_customcss") == "on") {
		echo '<link rel="stylesheet" type="text/css" media="all" href="'.get_bloginfo("template_directory").'/custom/custom.css" />';
	}
?>
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />
<?php
	/* We add some JavaScript to pages with the comment form
	 * to support sites with threaded comments (when in use).
	 */
	if ( is_singular() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	/*
	 * Adding robots and canonical url filter for better SEO
	 * simplybiz_create_robots() and simplybiz_canonical_url() in functions.php.
	 */
	 simplybiz_create_robots();
	 simplybiz_canonical_url();
	
	/* Always have wp_head() just before the closing </head>
	 * tag of your theme, or you will break many plugins, which
	 * generally use this hook to add elements to <head> such
	 * as styles, scripts, and meta tags.
	 */
	wp_head();
?>
</head>
<body <?php body_class(); ?>>
<div id="wrapper" class="hfeed">
	<div id="header">
		<div id="masthead" class="clearfix">
			<div id="branding" class="clearfix" role="banner">
            	<?php if(get_option("simplybiz_customlogo") == "") : ?>
				<div id="site-title"><a href="<?php echo home_url( '/' ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><img src="<?php bloginfo('template_directory'); ?>/library/images/logo.png" border="0" /></a></div>
                <div id="site-description"><?php bloginfo("description"); ?></div>
                <?php else : 
					echo '<a href="' .home_url('/'). '" rel="home">';
					echo '<img src="' . get_option("simplybiz_customlogo") . '" border="0" /></a>'; 
				endif; ?>
			</div><!-- #branding -->

			<div id="access" role="navigation">
			  <?php /*  Allow screen readers / text browsers to skip the navigation menu and get right to the good stuff */ ?>
				<div class="skip-link screen-reader-text"><a href="#content" title="<?php esc_attr_e( 'Skip to content', 'mobipress' ); ?>"><?php _e( 'Skip to content', 'mobipress' ); ?></a></div>
				<?php /* Our navigation menu.  If one isn't filled out, wp_nav_menu falls back to wp_page_menu.  The menu assiged to the primary position is the one used.  If none is assigned, the menu with the lowest ID is used.  */ ?>
				<?php
					$primary = '';
					$primary = wp_nav_menu( array( 'theme_location' => 'primary-menu', 'fallback_cb' => '', 'container_class' => 'menu', 'menu_class' => 'sf-menu', 'echo' => false, 'link_after' => '<span style="display:block;">&nbsp;</span>' ) );
					$primary = preg_replace('/(<a[^>]+>)([^\/]+)\/\/\/([^<]+)<span style="display:block;">&nbsp;<\/span>(<\/a>)/', '$1$2<span style="display:block;">$3&nbsp;</span>$4', $primary);
					if($primary <> "") :
						echo($primary);
					else : ?>
					<div class="menu">
						<ul class="sf-menu">
							<li><a href="<?php bloginfo("home"); ?>" title="<?php echo wp_specialchars( get_bloginfo('name'), 1 ) ?>" rel="home">
									Главная <span style="display:block;">Главная</span>
							</a></li>
							<?php foreach ( (get_pages('sort_column=menu_order') ) as $page ) { if ( $page->post_parent == '0' ) { ?>
							<li>
								<a href="<?php echo get_page_link($page->ID); ?>"><?php echo $page->post_title; ?> <span style="display:block; "><?php echo get_post_meta($page->ID, "Tagline", true); ?>&nbsp;</span></a>
                        
								<?php
								$child_pages = get_pages('child_of='.$page->ID);
								if (get_page_children($page->ID, $child_pages) ) { ?>
								<ul><?php wp_list_pages('title_li=&child_of=' . $page->ID ); ?></ul>
								<?php } ?>
							</li>
							<?php } } ?>
						</ul>
					</div>
					<?php endif; ?>
			</div><!-- #access -->
		</div><!-- #masthead -->
	</div><!-- #header -->
	
	<?php
    	/* Run the featured loop to output the portfolio,
		 * three service panel and breadcrumbs
		 */
		 if(is_home() || is_front_page()) :
		 	/* call portfolio */
			if(get_option('simplybiz_featured_slider') == 'on') { get_template_part( 'featured' ); }
			/* call panels */
			if(get_option('simplybiz_display_services') == 'on') : 
				get_template_part( 'panels' );
			endif;
			
		/* Display breadcrumb trail */
		else :
	?>
	<div id="breadcrumb">
		<?php include("breadcrumb.php"); ?>
	</div><!-- #breadcrumb -->
    <?php endif; ?>
    <?php if(!is_home() || !is_front_page()) : ?>
	<div class="separator"><!-- empty! --></div>
	<div id="main" class="<?php if(is_page_template('portfolio.php')) { echo 'fullpage '; } ?>clearfix">
    <?php endif; ?>
